UiColorScheme class

Defines the color palette for a UiThemeData.

All UI components resolve their colors from this scheme, making it the single source of truth for the visual identity.

Constructors

UiColorScheme({required Color primary, required Color onPrimary, required Color secondary, required Color onSecondary, required Color surface, required Color onSurface, required Color background, required Color onBackground, required Color error, required Color onError, required Color success, required Color onSuccess, required Color warning, required Color onWarning, required Color border, required Color shadow, Color? glow, List<Color>? gradient, Color? canvas, Color? surfaceRaised, Color? surfaceOverlay, Color? onSurfaceMuted, Color? onSurfaceSubtle})
const

Properties

background Color
final
border Color
final
canvas Color?
Optional semantic surface levels. Each falls back to the legacy palette.
final
error Color
final
glow Color?
Optional glow color for neon/cyberpunk styles.
final
gradient List<Color>?
Optional gradient colors for advanced designs.
final
hashCode int
The hash code for this object.
no setterinherited
onBackground Color
final
onError Color
final
onPrimary Color
final
onSecondary Color
final
onSuccess Color
final
onSurface Color
final
onSurfaceMuted Color?
final
onSurfaceSubtle Color?
final
onWarning Color
final
primary Color
final
resolvedBorderSubtle Color
no setter
resolvedCanvas Color
no setter
resolvedOnSurfaceMuted Color
no setter
resolvedOnSurfaceSubtle Color
no setter
resolvedSurfaceOverlay Color
no setter
resolvedSurfaceRaised Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
shadow Color
final
success Color
final
surface Color
final
surfaceOverlay Color?
final
surfaceRaised Color?
final
warning Color
final

Methods

copyWith({Color? primary, Color? onPrimary, Color? secondary, Color? onSecondary, Color? surface, Color? onSurface, Color? background, Color? onBackground, Color? error, Color? onError, Color? success, Color? onSuccess, Color? warning, Color? onWarning, Color? border, Color? shadow, Color? glow, List<Color>? gradient, Color? canvas, Color? surfaceRaised, Color? surfaceOverlay, Color? onSurfaceMuted, Color? onSurfaceSubtle}) UiColorScheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited