UiIconSet class

An application-wide icon replacement and rendering policy.

Keys are fallback icons exposed by UiIcons. Apps can replace any or all icons with glyphs from their own font without changing component code.

Constructors

UiIconSet({Map<IconData, IconData> replacements = const {}, double? weight, double? grade, double? opticalSize})
const

Properties

grade double?
final
hashCode int
The hash code for this object.
no setterinherited
opticalSize double?
final
replacements Map<IconData, IconData>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weight double?
final

Methods

copyWith({Map<IconData, IconData>? replacements, double? weight, double? grade, double? opticalSize}) UiIconSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(IconData fallback) IconData
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited