UiIcons class abstract final

Built-in icon set using Unicode/Material icon codes.

These use the MaterialIcons font family that ships with Flutter, so no extra font packages are needed.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

add → const IconData
apple → const IconData
arrowBack → const IconData
arrowDown → const IconData
arrowForward → const IconData
arrowUp → const IconData
bank → const IconData
cart → const IconData
check → const IconData
chevronLeft → const IconData
chevronRight → const IconData
circle → const IconData
clock → const IconData
close → const IconData
code → const IconData
copy → const IconData
creditCard → const IconData
darkMode → const IconData
dashboard → const IconData
decrement → const IconData
delete → const IconData
download → const IconData
edit → const IconData
email → const IconData
error → const IconData
expandLess → const IconData
expandMore → const IconData
facebook → const IconData
favorite → const IconData
favoriteBorder → const IconData
folder → const IconData
google → const IconData
group → const IconData
home → const IconData
homeFilled → const IconData
image → const IconData
increment → const IconData
info → const IconData
lightMode → const IconData
lock → const IconData
lockOpen → const IconData
maintenance → const IconData
moreHoriz → const IconData
moreVert → const IconData
notFound → const IconData
notifications → const IconData
offline → const IconData
palette → const IconData
payment → const IconData
person → const IconData
phone → const IconData
refresh → const IconData
remove → const IconData
settings → const IconData
share → const IconData
shipping → const IconData
star → const IconData
starBorder → const IconData
twitter → const IconData
unavailable → const IconData
upload → const IconData
userPlaceholder → const IconData
visibility → const IconData
visibilityOff → const IconData
warning → const IconData