UiTransitionStyle enum

Themed page transition styles.

Inheritance
Available extensions

Values

fade → const UiTransitionStyle

Fade in/out.

slideRight → const UiTransitionStyle

Slide from right (iOS-like).

slideUp → const UiTransitionStyle

Slide from bottom (modal-like).

scale → const UiTransitionStyle

Scale + fade (zoom in).

slideFade → const UiTransitionStyle

Slide + fade combined.

none → const UiTransitionStyle

No animation (instant).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UiTransitionStyle>
A constant List of the values in this enum, in order of their declaration.