UiDropdown<T> class
A themed dropdown menu.
UiDropdown<String>(
value: _selected,
items: ['Apple', 'Banana', 'Cherry'],
itemBuilder: (item) => Text(item),
onChanged: (v) => setState(() => _selected = v),
placeholder: 'Select fruit...',
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- UiDropdown
Constructors
Properties
- emptyText → String
-
final
- enabled → bool
-
final
- errorText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(T item)
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → bool
-
final
-
onChanged
→ ValueChanged<
T> -
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBuilder → Widget Function(T item)?
-
Custom builder for the selected value display.
If null, uses itemBuilder.
final
- value → T?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< UiDropdown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited