UiProduct class
Represents a product in the catalog.
Constructors
Properties
-
badges
→ List<
String> -
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
images
→ List<
String> -
final
- inStock → bool
-
final
- name → String
-
final
- price → double
-
final
- rating → double
-
final
- reviewCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salePrice → double?
-
final
Methods
-
copyWith(
{String? id, String? name, String? description, double? price, double? salePrice, List< String> ? images, double? rating, int? reviewCount, bool? inStock, List<String> ? badges}) → UiProduct -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited